@@ -4,14 +4,14 @@
     warning.level  = as.numeric(options("warn"))
     options("warn" = -1)
 
+    # require the utils package explicitly.
+    require(utils)
     # load graohviz and set the corresponding flag.
-    graphviz.enabled <<- require(Rgraphviz)
+    if ("Rgraphviz" %in% rownames(installed.packages()))
+      graphviz.enabled <<- require(Rgraphviz)
 
-    if (!graphviz.enabled)
-      if (!("Rgraphviz" %in% rownames(installed.packages())))
-        cat("Package Rgraphviz not installed.\n")
-      else
-        cat("Package Rgraphviz not loaded.\n")
+    cat("Package Rgraphviz", 
+      ifelse(graphviz.enabled, "loaded successfully.\n", "not loaded.\n"))
 
     # restore the original warning level.
     options("warn" = warning.level)
@@ -19,5 +19,5 @@
     # load the shared library.
     library.dynam("bnlearn", package = pkg, lib.loc = lib)
 
-}
+}#.ONLOAD
 
